@@ -1,7 +1,7 @@
 from typing import Any
 
 from rx import Observable
-from rx.subjects import Subject
+from rx.subject import Subject
 
 from interstate_py.stream_connection import StreamConnection
 
