@@ -1,4 +1,8 @@
+import asyncio
 from asyncio import Queue
+from concurrent.futures.thread import ThreadPoolExecutor
+
+import janus
 
 from interstate_py.connection_agent import ConnectionAgentBase
 from interstate_py.control.worker_task import AIOWorkerTask
@@ -7,6 +11,7 @@ from interstate_py.interstate_message import InterstateWireMessageType
 from interstate_py.log_factory import LogFactory
 from interstate_py.multiplex_message import MultiplexMessage
 from interstate_py.serialization.serialization import Serialization
+from interstate_py.stream_connection import StreamConnection
 
 
 class StreamDemultiplexer(AIOWorkerTask):
@@ -17,7 +22,7 @@ class StreamDemultiplexer(AIOWorkerTask):
     _log = LogFactory.get_logger(__name__)
 
     def __init__(self, raw_inbound_queue: Queue,
-                 outbound_queue: Queue,
+                 outbound_queue: janus.Queue,
                  con_agent: ConnectionAgentBase,
                  serialization: Serialization):  # TODO: interceptor
         super().__init__()
@@ -25,21 +30,29 @@ class StreamDemultiplexer(AIOWorkerTask):
         self._outbound_queue = outbound_queue
         self._con_agent = con_agent
         self._serialization = serialization
+        self._pool = ThreadPoolExecutor(5)
 
     async def do_work(self):
         message = await self._raw_inbound_queue.get()
         identity = message.identity.decode()
         connection = self._con_agent.get(identity)
 
-        # TODO: generify and decrease rx1 coupling
+        def _send(connection: StreamConnection, payload):
+            self._log.debug("Sending payload to subject")
+            connection.inbound_stream().on_next(payload)
+            self._log.debug("Payload sent to subject")
+
         if message.type == InterstateWireMessageType.NEXT:
             self._log.debug("[IN][NEXT] - {}".format(message))
             try:
                 deserialized_payload = self._serialization.deserialize(message.payload)
-                connection.inbound_stream().on_next(deserialized_payload)
+                asyncio.get_event_loop().run_in_executor(self._pool, #TODO: configurable
+                                                               _send,
+                                                               connection,
+                                                               deserialized_payload)
             except Exception as e:
                 self._log.warn("[IN][NEXT] - Could not deserialize incoming message: %s", ErrorAssembly.exc_message(e))
-                await self._outbound_queue.put(
+                await self._outbound_queue.async_q.put(
                     MultiplexMessage(message.identity.decode(), InterstateWireMessageType.ERROR,
                                      ErrorAssembly.to_error(ErrorAssembly.DESERIALIZATION_ERROR_TYPE,
                                                             e)))
@@ -54,7 +67,7 @@ class StreamDemultiplexer(AIOWorkerTask):
         elif message.type == InterstateWireMessageType.PING:
             # TODO: find a better way via interceptors or another mechanism
             self._log.debug("[IN][PING] - {}".format(message))
-            await self._outbound_queue.put(MultiplexMessage(identity, InterstateWireMessageType.PONG, "pong".encode()))
+            await self._outbound_queue.async_q.put(MultiplexMessage(identity, InterstateWireMessageType.PONG, "pong".encode()))
         else:
             self._log.warn("Can not handle message: {}".format(message))
 
