@@ -3,6 +3,7 @@ from asyncio import Queue
 from typing import Callable
 
 import aiozmq
+import janus
 import pkg_resources
 import zmq
 from rx import Observable
@@ -44,7 +45,7 @@ class AIOZMQServer(InterstateServer):
                                          raw_outbound_queue=raw_outbound_queue,
                                          control_queue=control_queue)
 
-        outbound_queue = Queue()
+        outbound_queue = janus.Queue()
         agent = RxConnectionAgent(self._evaluate_fn, outbound_queue=outbound_queue)
         demultiplexer = StreamDemultiplexer(raw_inbound_queue=inbound_wire_message_queue,
                                             outbound_queue=outbound_queue,
