@@ -25,7 +25,7 @@ class OutboundWorker(AIOWorkerTask):
         try:
             message_to_send = await self._outbound_queue.get()
             self._router.write(ZMsgAssembly.assemble(message_to_send))
-            self._log.info("[OUT][SOCKET]: Written: {}".format(message_to_send))
+            self._log.debug("[OUT][SOCKET]: Written: {}".format(message_to_send))
             self._outbound_queue.task_done()
         except Exception as e:
             self._log.error(e)
